@@ -11,9 +11,9 @@ SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "decorationpalette.h"
 
+#include <KColorScheme>
 #include <KConfigGroup>
 #include <KSharedConfig>
-#include <KColorScheme>
 
 #include <QFileInfo>
 #include <QStandardPaths>
@@ -22,11 +22,8 @@ namespace KWin
 {
 namespace Decoration
 {
-
 DecorationPalette::DecorationPalette(const QString &colorScheme)
-    : m_colorScheme(QFileInfo(colorScheme).isAbsolute()
-                    ? colorScheme
-                    : QStandardPaths::locate(QStandardPaths::GenericConfigLocation, colorScheme))
+    : m_colorScheme(QFileInfo(colorScheme).isAbsolute() ? colorScheme : QStandardPaths::locate(QStandardPaths::GenericConfigLocation, colorScheme))
 {
     if (!m_colorScheme.startsWith(QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation)) && colorScheme == QStringLiteral("kdeglobals")) {
         // kdeglobals doesn't exist so create it. This is needed to monitor it using QFileSystemWatcher.
@@ -54,41 +51,41 @@ bool DecorationPalette::isValid() const
 
 QColor DecorationPalette::color(KDecoration2::ColorGroup group, KDecoration2::ColorRole role) const
 {
-    using KDecoration2::ColorRole;
     using KDecoration2::ColorGroup;
+    using KDecoration2::ColorRole;
 
     switch (role) {
-        case ColorRole::Frame:
-            switch (group) {
-                case ColorGroup::Active:
-                    return m_activeFrameColor;
-                case ColorGroup::Inactive:
-                    return m_inactiveFrameColor;
-                default:
-                    return QColor();
-            }
-        case ColorRole::TitleBar:
-            switch (group) {
-                case ColorGroup::Active:
-                    return m_activeTitleBarColor;
-                case ColorGroup::Inactive:
-                    return m_inactiveTitleBarColor;
-                default:
-                    return QColor();
-            }
-        case ColorRole::Foreground:
-            switch (group) {
-                case ColorGroup::Active:
-                    return m_activeForegroundColor;
-                case ColorGroup::Inactive:
-                    return m_inactiveForegroundColor;
-                case ColorGroup::Warning:
-                    return m_warningForegroundColor;
-                default:
-                    return QColor();
-            }
+    case ColorRole::Frame:
+        switch (group) {
+        case ColorGroup::Active:
+            return m_activeFrameColor;
+        case ColorGroup::Inactive:
+            return m_inactiveFrameColor;
         default:
             return QColor();
+        }
+    case ColorRole::TitleBar:
+        switch (group) {
+        case ColorGroup::Active:
+            return m_activeTitleBarColor;
+        case ColorGroup::Inactive:
+            return m_inactiveTitleBarColor;
+        default:
+            return QColor();
+        }
+    case ColorRole::Foreground:
+        switch (group) {
+        case ColorGroup::Active:
+            return m_activeForegroundColor;
+        case ColorGroup::Inactive:
+            return m_inactiveForegroundColor;
+        case ColorGroup::Warning:
+            return m_warningForegroundColor;
+        default:
+            return QColor();
+        }
+    default:
+        return QColor();
     }
 }
 
@@ -108,16 +105,15 @@ void DecorationPalette::update()
 
     m_palette = KColorScheme::createApplicationPalette(config);
 
-    m_activeFrameColor        = wmConfig.readEntry("frame", m_palette.color(QPalette::Active, QPalette::Window));
-    m_inactiveFrameColor      = wmConfig.readEntry("inactiveFrame", m_activeFrameColor);
-    m_activeTitleBarColor     = wmConfig.readEntry("activeBackground", m_palette.color(QPalette::Active, QPalette::Highlight));
-    m_inactiveTitleBarColor   = wmConfig.readEntry("inactiveBackground", m_inactiveFrameColor);
-    m_activeForegroundColor   = wmConfig.readEntry("activeForeground", m_palette.color(QPalette::Active, QPalette::HighlightedText));
+    m_activeFrameColor = wmConfig.readEntry("frame", m_palette.color(QPalette::Active, QPalette::Window));
+    m_inactiveFrameColor = wmConfig.readEntry("inactiveFrame", m_activeFrameColor);
+    m_activeTitleBarColor = wmConfig.readEntry("activeBackground", m_palette.color(QPalette::Active, QPalette::Highlight));
+    m_inactiveTitleBarColor = wmConfig.readEntry("inactiveBackground", m_inactiveFrameColor);
+    m_activeForegroundColor = wmConfig.readEntry("activeForeground", m_palette.color(QPalette::Active, QPalette::HighlightedText));
     m_inactiveForegroundColor = wmConfig.readEntry("inactiveForeground", m_activeForegroundColor.darker());
 
     KConfigGroup windowColorsConfig(config, QStringLiteral("Colors:Window"));
     m_warningForegroundColor = windowColorsConfig.readEntry("ForegroundNegative", QColor(237, 21, 2));
-
 }
 
 }
